SystemOrganization addCategory: #'Neo-JSON-Tests'!

TestCase subclass: #NeoJSONBenchmarkTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Neo-JSON-Tests'!

!NeoJSONBenchmarkTests commentStamp: 'SvenVanCaekenberghe 6/5/2012 10:05' prior: 0!
I am NeoJSONBenchmarkTests.

This test is obviously dependent on hardware, but the margin is quite high.!

!NeoJSONBenchmarkTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/10/2012 20:20'!
testObject2
	| json |
	json := NeoJSONWriter toString: NeoJSONTestObject2 new.
	self 
		assert: (NeoJSONReader fromString: json as: NeoJSONTestObject2)
		equals: NeoJSONTestObject2 new! !

!NeoJSONBenchmarkTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/15/2014 19:29'!
testPrettyPrinted
	| benchmark |
	benchmark := NeoJSONBenchmark new.
	self
		assert: benchmark writePrettyPrintedRead
		equals: benchmark read! !

!NeoJSONBenchmarkTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/15/2014 19:30'!
testRead
	| benchmark |
	benchmark := NeoJSONBenchmark new.
	benchmark read! !

!NeoJSONBenchmarkTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/15/2014 19:30'!
testWrite
	| benchmark |
	benchmark := NeoJSONBenchmark new.
	benchmark write! !

TestCase subclass: #NeoJSONReaderTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Neo-JSON-Tests'!

!NeoJSONReaderTests commentStamp: 'SvenVanCaekenberghe 6/2/2012 14:02' prior: 0!
I am NeoJSONReaderTests, a test suite for NeoJSONReader.!

!NeoJSONReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/12/2012 12:32'!
testArrayOfPoints
	| reader |
	reader := [ :string | 
		(NeoJSONReader on: string readStream) 
			for: Point do: [ :mapping |
				mapping mapInstVars: #(x y) ];
			for: #ArrayOfPoints customDo: [ :mapping |
				mapping listOfElementSchema: Point ];
			nextAs: #ArrayOfPoints ].
	self assert: (reader value: '[ { "x":1, "y":2 }, { "x":-1, "y":-2 } ]') equals: { 1@2. -1@ -2 }. 
	self assert: (reader value: '[ ]') equals: #().
	self assert: (reader value: '[ { } ]') equals: { Point new }! !

!NeoJSONReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/12/2012 13:18'!
testAssociation
	| reader |
	reader := [ :string | 
		(NeoJSONReader on: string readStream) 
			for: Association do: [ :mapping |
				mapping mapAccessors: #(key value) ]; 
			nextAs: Association ].
	self assert: (reader value: '{"key":"foo","value":42}') equals: 'foo' -> 42. 
	self assert: (reader value: '{}') equals: Association new! !

!NeoJSONReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/13/2012 14:44'!
testBooleans
	self assert: (NeoJSONReader on: 'true' readStream) next equals: true.
	self assert: (NeoJSONReader on: 'false' readStream) next equals: false.
	self should: [ (NeoJSONReader on: 'tru' readStream) next ] raise: NeoJSONParseError.
	self should: [ (NeoJSONReader on: 'falsE' readStream) next ] raise: NeoJSONParseError.! !

!NeoJSONReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/12/2012 12:32'!
testByteArray
	| reader |
	reader := [ :string | 
		(NeoJSONReader on: string readStream) 
			for: ByteArray customDo: [ :mapping |
				mapping listOfType: ByteArray ];
			nextAs: ByteArray ].
	self assert: (reader value: '[ 1, 2, 3 ]') equals: #[1 2 3].
	self assert: (reader value: '[ ]') equals: ByteArray new! !

!NeoJSONReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/12/2012 12:02'!
testDate
	| reader |
	reader := [ :input | 
		(NeoJSONReader on: input readStream) 
			for: Date customDo: [ :mapping |
				mapping decoder: [ :string | Date fromString: string ] ];
			nextAs: Date ].
	self assert: (reader value: ' "2012-06-08" ') equals: (Date newDay: 8 month: 6 year: 2012)! !

!NeoJSONReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/12/2012 12:02'!
testDateAndTime 
	| reader |
	reader := [ :input | 
		(NeoJSONReader on: input readStream) 
			for: DateAndTime customDo: [ :mapping |
				mapping decoder: [ :string | DateAndTime fromString: string ] ];
			nextAs: DateAndTime ].
	self 
		assert: (reader value: ' "2012-02-14T16:40:18+01:00" ') 
		equals: (DateAndTime year: 2012 month: 2 day: 14 hour: 16 minute: 40 second: 18 offset: 1 hour)! !

!NeoJSONReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/2/2012 21:49'!
testFloats
	| reader |
	reader := [ :string |
		(NeoJSONReader on: string readStream) next ].
	self assert: ((reader value: '123.0') closeTo: 123.0).
	self assert: ((reader value: '-123.0') closeTo: -123.0).
	self assert: ((reader value: '123.0e0') closeTo: 123.0).
	self assert: ((reader value: '123e6') closeTo: 123e6).
	self assert: ((reader value: '123e+6') closeTo: 123e6).
	self assert: ((reader value: '123e-6') closeTo: 123e-6).
	self assert: ((reader value: '123E6') closeTo: 123e6).
	self assert: ((reader value: '123E+6') closeTo: 123e6).
	self assert: ((reader value: '123E-6') closeTo: 123e-6).
	self assert: ((reader value: '-123e6') closeTo: -123e6).
	self assert: ((reader value: '-123e-6') closeTo: -123e-6).
	self assert: ((reader value: '-123E6') closeTo: -123e6).
	self assert: ((reader value: '-123E-6') closeTo: -123e-6).
	self assert: ((reader value: '3.14159') closeTo: Float pi).
	self assert: ((reader value: '0.123e6') closeTo: 0.123e6).
	self assert: ((reader value: '0.123e-6') closeTo: 0.123e-6).
	self assert: ((reader value: '-0.123E6') closeTo: -0.123e6).
	self assert: ((reader value: '-0.123E-6') closeTo: -0.123e-6).
! !

!NeoJSONReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/12/2012 16:08'!
testIntegers
	| reader |
	reader := [ :string |
		(NeoJSONReader on: string readStream) next ].
	self assert: (reader value: '123') equals: 123.
	self assert: (reader value: '00123') equals: 123.
	self assert: (reader value: '-123') equals: -123.
	self assert: (reader value: '-0123') equals: -123.
	self assert: (reader value: '0') equals: 0.
	self assert: (reader value: '-0') equals: 0.
	self assert: (reader value: '00') equals: 0.
	self assert: (reader value: ' 123	') equals: 123.
	self should: [ reader value: '+1' ] raise: NeoJSONParseError.
	self should: [ reader value: ' - ' ] raise: NeoJSONParseError.
! !

!NeoJSONReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/12/2012 16:16'!
testLists
	| reader |
	reader := [ :string |
		(NeoJSONReader on: string readStream) next ].
	self assert: (reader value: '[1,2,3]') equals: #(1 2 3).
	self assert: (reader value: '[]') equals: #().
	self assert: (reader value: ' [ 1 , 2 , 3 ] ') equals: #(1 2 3).
	self assert: (reader value: ' [ ] ') equals: #().
	self should: [ reader value: '[1,]' ] raise: NeoJSONParseError. 
	self should: [ reader value: '[' ] raise: NeoJSONParseError.
	self should: [ reader value: ']' ] raise: NeoJSONParseError.
	self should: [ reader value: '[}' ] raise: NeoJSONParseError! !

!NeoJSONReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/12/2012 16:16'!
testMaps
	| reader |
	reader := [ :string |
		(NeoJSONReader on: string readStream) next ].
	self assert: (reader value: '{"x":1,"y":2}') equals: (Dictionary newFromPairs: #( 'x' 1 'y' 2)).
	self assert: (reader value: '{}') equals: Dictionary new.
	self assert: (reader value: ' { "x" : 1 , "y" : 2 } ' ) equals: (Dictionary newFromPairs: #( 'x' 1 'y' 2)).
	self assert: (reader value: ' { } ') equals: Dictionary new.
	self should: [ reader value: '{"foo":}' ] raise: NeoJSONParseError. 
	self should: [ reader value: '{"foo":9,}' ] raise: NeoJSONParseError. 
	self should: [ reader value: '{9:true,}' ] raise: NeoJSONParseError. 
	self should: [ reader value: '{' ] raise: NeoJSONParseError.
	self should: [ reader value: '}' ] raise: NeoJSONParseError.
	self should: [ reader value: '{]' ] raise: NeoJSONParseError! !

!NeoJSONReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/24/2014 11:58'!
testNextStringAsHex
	| string |
	string := (NeoJSONReader on: '"466F6F2062617221"' readStream)
		for: #StringAsHex
			customDo: [ :mapping | 
					mapping
						encoder: [ :x | x asByteArray hex asUppercase ];
						decoder: [ :x | (ByteArray readHexFrom: x) asString ] ];
		nextAs: #StringAsHex.
	self assert: string equals: 'Foo bar!!'! !

!NeoJSONReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/13/2012 14:29'!
testNull
	self assert: (NeoJSONReader on: 'null' readStream) next equals: nil.
	self assert: (NeoJSONReader on: '	null ' readStream) next equals: nil.
	self should: [ (NeoJSONReader on: '	nil ' readStream) next ] raise: NeoJSONParseError.! !

!NeoJSONReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/13/2012 10:18'!
testOrderedCollection
	| json list |
	json := '[ 1, 2, 3 ]'.
	list := (NeoJSONReader on: json readStream) 
		listClass: OrderedCollection;
		next.
	self 
		assert: list 
		equals: (OrderedCollection with: 1 with: 2 with: 3).
	self 
		assert: list class 
		equals: OrderedCollection! !

!NeoJSONReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/12/2012 12:33'!
testOrderedCollectionOfPoints
	| reader |
	reader := [ :string | 
		(NeoJSONReader on: string readStream) 
			for: Point do: [ :mapping |
				mapping mapInstVars: #(x y) ];
			for: #OrderedCollectionOfPoints customDo: [ :mapping |
				mapping listOfType: OrderedCollection andElementSchema: Point ];
			nextAs: #OrderedCollectionOfPoints ].
	self assert: (reader value: '[ { "x":1, "y":2 }, { "x":-1, "y":-2 } ]') equals: { 1@2. -1@ -2 } asOrderedCollection. 
	self assert: (reader value: '[ ]') equals: OrderedCollection new.
	self assert: (reader value: '[ { } ]') equals: (OrderedCollection with: Point new)! !

!NeoJSONReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/12/2012 16:01'!
testParseErrors
	self should: [ NeoJSONReader fromString: 'zero' ] raise: NeoJSONParseError.
	self should: [ NeoJSONReader fromString: '#' ] raise: NeoJSONParseError.
	self should: [ NeoJSONReader fromString: '@' ] raise: NeoJSONParseError.! !

!NeoJSONReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/12/2012 15:58'!
testPoint
	| reader |
	reader := [ :string | 
		(NeoJSONReader on: string readStream) nextAs: Point ].
	self should: [ reader value: '{"x":1,"y":2}' ] raise: NeoJSONMappingNotFound! !

!NeoJSONReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/8/2012 14:04'!
testPoint1
	| reader |
	reader := [ :string | 
		(NeoJSONReader on: string readStream) 
			for: Point do: [ :mapping |
				mapping mapProperty: 'x' getter: [ :point | point x ] setter: [ :point :value | point setX: value setY: point y ].
				mapping mapProperty: 'y' getter: [ :point | point y ] setter: [ :point :value | point setX: point x setY: value ]. ];
			nextAs: Point ].
	self assert: (reader value: '{"x":1,"y":2}') equals: 1@2. 
	self assert: (reader value: '{}') equals: Point new! !

!NeoJSONReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/7/2012 15:23'!
testPoint2
	| reader |
	reader := [ :string | 
		(NeoJSONReader on: string readStream) 
			mapAllInstVarsFor: Point;
			nextAs: Point ].
	self assert: (reader value: '{"x":1,"y":2}') equals: 1@2. 
	self assert: (reader value: '{}') equals: Point new! !

!NeoJSONReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/8/2012 14:04'!
testPoint3
	| reader |
	reader := [ :string | 
		(NeoJSONReader on: string readStream) 
			for: Point do: [ :mapping |
				mapping mapInstVars: #(x y) ];
			nextAs: Point ].
	self assert: (reader value: '{"x":1,"y":2}') equals: 1@2. 
	self assert: (reader value: '{}') equals: Point new! !

!NeoJSONReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/24/2014 10:43'!
testPointUsingAsString
	| point |
	point := (NeoJSONReader on: '{"x":"1","y":"2"}' readStream)
		for: Point
			do: [ :mapping | 
					(mapping 
						mapProperty: #x 
						getter: [ :object | object x ] 
						setter: [ :object :value | object setX: value setY: object y ])
						valueSchema: #AsString.
					(mapping
						mapProperty: #y
						getter: [ :object | object y ]
						setter: [ :object :value | object setX: object x setY: value ]) 
						valueSchema: #AsString ];
		for: #AsString
			customDo: [ :mapping | 
					mapping
						encoder: [ :x | x asString ];
						decoder: [ :x | x asNumber ] ];
		nextAs: Point.
	self assert: point equals: 1 @ 2! !

!NeoJSONReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/13/2012 10:00'!
testPropertyNamesAsSymbols
	| json map |
	json := '{ "x" : true, "y" : false, "key-1" : 1 }'.
	map := (NeoJSONReader on: json readStream) 
		propertyNamesAsSymbols: true; 
		next.
	self 
		assert: map 
		equals: (Dictionary new at: #x put: true; at: #y put: false; at: #'key-1' put: 1; yourself).
	self assert: (map keys allSatisfy: [ :each | each isSymbol ])! !

!NeoJSONReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 7/4/2013 18:38'!
testSmallDictionary
	| json map smallDictionaryClass |
	json := '{ "x" : true, "y" : false, "key-1" : 1 }'.
	smallDictionaryClass := Smalltalk at: #SmallDictionary ifAbsent: [ Dictionary ].
	map := (NeoJSONReader on: json readStream) 
		mapClass: smallDictionaryClass;
		next.
	self 
		assert: map 
		equals: (smallDictionaryClass new at: #x put: true; at: #y put: false; at: #'key-1' put: 1; yourself).
	self 
		assert: map class 
		equals: smallDictionaryClass! !

!NeoJSONReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/12/2012 16:04'!
testStrings
	| reader |
	reader := [ :string |
		(NeoJSONReader on: string readStream) next ].
	self assert: (reader value: '"foo"') equals: 'foo'.
	self assert: (reader value: '""') equals: ''.
	self assert: (reader value: '"Foo BAR"') equals: 'Foo BAR'.
	self assert: (reader value: '"\u00E9l\u00E8ve en Fran\u00E7ais"') equals: 'élève en Français'.
	self 
		assert: (reader value: '"\"\\\/\t\r\n\f\b"') 
		equals: (String withAll: { 
					$". $\. $/. Character tab. Character cr. Character lf.  Character newPage. Character backspace }).
	self should: [ reader value: '"open' ] raise: NeoJSONParseError.
	self should: [ reader value: '"\uAA"' ] raise: NeoJSONParseError.
	self should: [ reader value: '"\uZZ"' ] raise: NeoJSONParseError.
	self should: [ reader value: '"\x"' ] raise: NeoJSONParseError.
	self should: [ reader value: ' " ' ] raise: NeoJSONParseError.
! !

!NeoJSONReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/12/2012 12:02'!
testSymbol
	| reader |
	reader := [ :input | 
		(NeoJSONReader on: input readStream) 
			for: Symbol customDo: [ :mapping |
				mapping decoder: [ :string | string asSymbol ] ];
			nextAs: Symbol ].
	self assert: (reader value: ' "foo" ') equals: #foo.
	self assert: (reader value: ' "FOO-1" ') equals: #'FOO-1'! !

!NeoJSONReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/12/2012 12:02'!
testTime
	| reader |
	reader := [ :input | 
		(NeoJSONReader on: input readStream) 
			for: Time customDo: [ :mapping |
				mapping decoder: [ :string | Time fromString: string ] ];
			nextAs: Time ].
	self assert: (reader value: ' "14:30:08" ') equals: (Time hour: 14 minute: 30 second: 8)! !

TestCase subclass: #NeoJSONWriteReadTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Neo-JSON-Tests'!

!NeoJSONWriteReadTests commentStamp: 'SvenVanCaekenberghe 6/4/2012 15:34' prior: 0!
I am NeoJSONWriteReadTests.!

NeoJSONWriteReadTests subclass: #NeoJSONWriteReadMockStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Neo-JSON-Tests'!

!NeoJSONWriteReadMockStreamTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 6/13/2012 16:28'!
writeRead: object
	| json |
	json := String streamContents: [ :stream |
		(NeoJSONWriter on: (NeoJSONMockStream on: stream))
			prettyPrint: true;
			nextPut: object ].
	^ (NeoJSONReader on: (NeoJSONMockStream on: json readStream)) next ! !

NeoJSONWriteReadTests subclass: #NeoJSONWriteReadPrettyPrintedTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Neo-JSON-Tests'!

!NeoJSONWriteReadPrettyPrintedTests commentStamp: 'SvenVanCaekenberghe 6/5/2012 09:50' prior: 0!
I am NeoJSONWriteReadPrettyPrintedTests.!

!NeoJSONWriteReadPrettyPrintedTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/30/2013 11:05'!
testDictionaryOfObject2
	| data json reader |
	data := Dictionary new.
	data 
		at: #one put: NeoJSONTestObject2 example1;
		at: #two put: NeoJSONTestObject2 example1.
	json := NeoJSONWriter toStringPretty: data.
	reader := NeoJSONReader on: json readStream.
	reader for: #DictionaryOfObject2 customDo: [ :mapping |
		mapping mapWithValueSchema: NeoJSONTestObject2 ].  
	self 
		assert: (reader nextAs: #DictionaryOfObject2)
		equals: data! !

!NeoJSONWriteReadPrettyPrintedTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/9/2012 18:49'!
testObject1
	| json |
	json := NeoJSONWriter toStringPretty: NeoJSONTestObject1 example1.
	self 
		assert: (NeoJSONReader fromString: json as: NeoJSONTestObject1)
		equals: NeoJSONTestObject1 example1! !

!NeoJSONWriteReadPrettyPrintedTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/30/2013 11:05'!
testObject2
	| json |
	json := NeoJSONWriter toStringPretty: NeoJSONTestObject2 example1.
	self 
		assert: (NeoJSONReader fromString: json as: NeoJSONTestObject2)
		equals: NeoJSONTestObject2 example1! !

!NeoJSONWriteReadPrettyPrintedTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/22/2014 10:59'!
testObject3
	| json |
	json := NeoJSONWriter toStringPretty: NeoJSONTestObject3 example1.
	self 
		assert: (NeoJSONReader fromString: json as: NeoJSONTestObject3)
		equals: NeoJSONTestObject3 example1! !

!NeoJSONWriteReadPrettyPrintedTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 6/4/2012 15:45'!
writeRead: object
	| json |
	json := String streamContents: [ :stream |
		(NeoJSONWriter on: stream) 
			prettyPrint: true;
			nextPut: object ].
	^ (NeoJSONReader on: json readStream) next ! !

!NeoJSONWriteReadTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/30/2013 11:03'!
testDictionaryOfObject2
	| data json reader |
	data := Dictionary new.
	data 
		at: #one put: NeoJSONTestObject2 example1;
		at: #two put: NeoJSONTestObject2 example1.
	json := NeoJSONWriter toString: data.
	reader := NeoJSONReader on: json readStream.
	reader for: #DictionaryOfObject2 customDo: [ :mapping |
		mapping mapWithValueSchema: NeoJSONTestObject2 ].  
	self 
		assert: (reader nextAs: #DictionaryOfObject2)
		equals: data! !

!NeoJSONWriteReadTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/4/2012 15:51'!
testFloats
	| objects |
	objects := { Float pi . 1.0 . -1.0 . 0.0 . 1.5e6 . -1.5e6 . 1.5e-6 . -1.5e-6 }.
	(self writeRead: objects) 
		with: objects 
		do: [ :first :second | self assert: (first closeTo: second) ]! !

!NeoJSONWriteReadTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/4/2012 15:46'!
testIntegers
	| objects |
	objects := { 1. -1. 0. 123467890. -1234567890 }.
	self 
		assert: (self writeRead: objects)
		equals: objects! !

!NeoJSONWriteReadTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/4/2012 15:51'!
testLists
	| objects |
	objects := { #(1 2 3). #(). #( 'foo' 'bar') }.
	self 
		assert: (self writeRead: objects)
		equals: objects! !

!NeoJSONWriteReadTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/4/2012 15:53'!
testMaps
	| objects |
	objects := { 
		Dictionary new.
		Dictionary with: 'x' -> 1.
		Dictionary newFromPairs: #( 'foo' true 'bar' false 'zero' 0 'null' nil 'string' 'Hello World!!' ) }.
	self 
		assert: (self writeRead: objects)
		equals: objects! !

!NeoJSONWriteReadTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/9/2012 18:48'!
testObject1
	| json |
	json := NeoJSONWriter toString: NeoJSONTestObject1 example1.
	self 
		assert: (NeoJSONReader fromString: json as: NeoJSONTestObject1)
		equals: NeoJSONTestObject1 example1! !

!NeoJSONWriteReadTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/30/2013 10:12'!
testObject2
	| json |
	json := NeoJSONWriter toString: NeoJSONTestObject2 example1.
	self 
		assert: (NeoJSONReader fromString: json as: NeoJSONTestObject2)
		equals: NeoJSONTestObject2 example1! !

!NeoJSONWriteReadTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/22/2014 10:14'!
testObject3
	| json |
	json := NeoJSONWriter toString: NeoJSONTestObject3 example1.
	self 
		assert: (NeoJSONReader fromString: json as: NeoJSONTestObject3)
		equals: NeoJSONTestObject3 example1! !

!NeoJSONWriteReadTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/4/2012 15:46'!
testSpecials
	| objects |
	objects := { true. false. nil }.
	self 
		assert: (self writeRead: objects)
		equals: objects! !

!NeoJSONWriteReadTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/10/2012 21:15'!
testStrings
	| objects |
	objects := { 'foo'. 'Foo BAR'. ''. '	\\'''. 'élève en Français' }.
	self 
		assert: (self writeRead: objects)
		equals: objects! !

!NeoJSONWriteReadTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 6/4/2012 15:36'!
writeRead: object
	| json |
	json := String streamContents: [ :stream |
		(NeoJSONWriter on: stream) nextPut: object ].
	^ (NeoJSONReader on: json readStream) next ! !

TestCase subclass: #NeoJSONWriterTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Neo-JSON-Tests'!

!NeoJSONWriterTests commentStamp: 'SvenVanCaekenberghe 6/2/2012 22:20' prior: 0!
I am NeoJSONWriterTests, a test suite for NeoJSONWriter.!

!NeoJSONWriterTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/3/2013 12:06'!
testAsciiOnlyStrings
	| writer |
	writer := [ :object | 
		String streamContents: [ :stream |
			(NeoJSONWriter on: stream) 
				asciiOnly: true;
				nextPut: object ] ].
	self assert: (writer value: 'élève français') equals: '"\u00E9l\u00E8ve fran\u00E7ais"'.
	self assert: (writer value: 'foo') equals: '"foo"'.
	self assert: (writer value: 'Foo BAR') equals: '"Foo BAR"'.
	self assert: (writer value: '') equals: '""'.
	self
		assert: (writer value: (String withAll: { 
					$". $\. $/. Character tab. Character cr. Character lf.  Character newPage. Character backspace }))
		equals: '"\"\\/\t\r\n\f\b"'

! !

!NeoJSONWriterTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/12/2012 13:19'!
testAssociation
	| writer |
	writer := [ :object | 
		String streamContents: [ :stream |
			(NeoJSONWriter on: stream) 
				for: Association do: [ :mapping |
					mapping mapAccessors: #(key value) ]; 
				nextPut: object ] ].
	self assert: (writer value: 'foo' -> 42) equals: '{"key":"foo","value":42}'.
	self assert: (writer value: Association new) equals: '{}'! !

!NeoJSONWriterTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/3/2012 19:56'!
testBooleans
	| writer |
	writer := [ :object | 
		String streamContents: [ :stream |
			(NeoJSONWriter on: stream) nextPut: object ] ].
	self assert: (writer value: true) equals: 'true'.
	self assert: (writer value: false) equals: 'false'.! !

!NeoJSONWriterTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/8/2012 21:54'!
testByteArray
	| writer |
	writer := [ :object | 
		String streamContents: [ :stream |
			(NeoJSONWriter on: stream) nextPut: object ] ].
	self assert: (writer value: #[1 2 3]) equals: '[1,2,3]'.
	self assert: (writer value: #[]) equals: '[]'
! !

!NeoJSONWriterTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/12/2012 12:02'!
testDate
	| writer |
	writer := [ :object | 
		String streamContents: [ :stream |
			(NeoJSONWriter on: stream) 
				for: Date customDo: [ :mapping |
					mapping encoder: [ :date | date yyyymmdd ] ];
				nextPut: object ] ].
	self assert: (writer value: (Date newDay: 8 month: 6 year: 2012)) equals: '"2012-06-08"'! !

!NeoJSONWriterTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/12/2012 12:02'!
testDateAndTime 
	| writer |
	writer := [ :object | 
		String streamContents: [ :stream |
			(NeoJSONWriter on: stream) 
				for: DateAndTime customDo: [ :mapping |
					mapping encoder: [ :dateAndTime | dateAndTime printString ] ];
				nextPut: object ] ].
	self 
		assert: (writer value: (DateAndTime year: 2012 month: 2 day: 14 hour: 16 minute: 40 second: 18 offset: 1 hour)) 
		equals: '"2012-02-14T16:40:18+01:00"'! !

!NeoJSONWriterTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/2/2012 22:24'!
testFloats
	| writer |
	writer := [ :object | 
		String streamContents: [ :stream |
			(NeoJSONWriter on: stream) nextPut: object ] ].
	self assert: (writer value: 123.0) equals: '123.0'.
	self assert: (writer value: -123.0) equals: '-123.0'.
	self assert: (writer value: 0.0) equals: '0.0'.! !

!NeoJSONWriterTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/2/2012 22:24'!
testIntegers
	| writer |
	writer := [ :object | 
		String streamContents: [ :stream |
			(NeoJSONWriter on: stream) nextPut: object ] ].
	self assert: (writer value: 123) equals: '123'.
	self assert: (writer value: -123) equals: '-123'.
	self assert: (writer value: 0) equals: '0'.! !

!NeoJSONWriterTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/3/2012 19:39'!
testLists
	| writer |
	writer := [ :object | 
		String streamContents: [ :stream |
			(NeoJSONWriter on: stream) nextPut: object ] ].
	self assert: (writer value: #(1 2 3)) equals: '[1,2,3]'.
	self assert: (writer value: #()) equals: '[]'.
! !

!NeoJSONWriterTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/3/2012 19:40'!
testMaps
	| writer |
	writer := [ :object | 
		String streamContents: [ :stream |
			(NeoJSONWriter on: stream) nextPut: object ] ].
	self assert: (writer value: (Dictionary newFromPairs: #( 'x' 1 'y' 2))) equals: '{"x":1,"y":2}'.
	self assert: (writer value: Dictionary new) equals: '{}'.
! !

!NeoJSONWriterTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/24/2014 11:57'!
testNextPutStringAsHex
	| output |
	output := String
		streamContents: [ :out | 
			(NeoJSONWriter on: out)
				for: #StringAsHex
					customDo: [ :mapping | 
							mapping
								encoder: [ :x | x asByteArray hex asUppercase ];
								decoder: [ :x | (ByteArray readHexFrom: x) asString ] ];
				nextPut: 'Foo bar!!' as: #StringAsHex ].
	self assert: output equals: '"466F6F2062617221"'! !

!NeoJSONWriterTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/2/2012 22:23'!
testNull
	| writer |
	writer := [ :object | 
		String streamContents: [ :stream |
			(NeoJSONWriter on: stream) nextPut: object ] ].
	self assert: (writer value: nil) equals: 'null'! !

!NeoJSONWriterTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/12/2012 15:58'!
testPoint
	| writer |
	writer := [ :object | 
		String streamContents: [ :stream |
			(NeoJSONWriter on: stream) nextPut: object ] ].
	self should: [ writer value: 1@2 ] raise: NeoJSONMappingNotFound! !

!NeoJSONWriterTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/8/2012 14:04'!
testPoint1
	| writer |
	writer := [ :object | 
		String streamContents: [ :stream |
			(NeoJSONWriter on: stream) 
				for: Point do: [ :mapping |
					mapping mapProperty: 'x' getter: [ :point | point x ] setter: [ :point :value | point x: value ].
					mapping mapProperty: 'y' getter: [ :point | point y ] setter: [ :point :value | point y: value ]. ];
				nextPut: object ] ].
	self assert: (writer value: 1@2) equals: '{"x":1,"y":2}'.
	self assert: (writer value: Point new) equals: '{}'! !

!NeoJSONWriterTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/6/2012 17:29'!
testPoint2
	| writer |
	writer := [ :object | 
		String streamContents: [ :stream |
			(NeoJSONWriter on: stream) 
				mapAllInstVarsFor: Point;
				nextPut: object ] ].
	self assert: (writer value: 1@2) equals: '{"x":1,"y":2}'.
	self assert: (writer value: Point new) equals: '{}'! !

!NeoJSONWriterTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/8/2012 14:04'!
testPoint3
	| writer |
	writer := [ :object | 
		String streamContents: [ :stream |
			(NeoJSONWriter on: stream) 
				for: Point do: [ :mapping |
					mapping mapInstVars: #(x y) ];
				nextPut: object ] ].
	self assert: (writer value: 1@2) equals: '{"x":1,"y":2}'.
	self assert: (writer value: Point new) equals: '{}'! !

!NeoJSONWriterTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/24/2014 10:41'!
testPointUsingAsString
	| output |
	output := String
		streamContents: [ :out | 
			(NeoJSONWriter on: out)
				for: Point
					do: [ :mapping | 
							(mapping 
								mapProperty: #x 
								getter: [ :object | object x ] 
								setter: [ :object :value | object setX: value setY: object y ])
								valueSchema: #AsString.
							(mapping
								mapProperty: #y
								getter: [ :object | object y ]
								setter: [ :object :value | object setX: object x setY: value ]) 
								valueSchema: #AsString ];
				for: #AsString
					customDo: [ :mapping | 
							mapping
								encoder: [ :x | x asString ];
								decoder: [ :x | x asNumber ] ];
				nextPut: 1 @ 2 ].
	self assert: output equals: '{"x":"1","y":"2"}'! !

!NeoJSONWriterTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/10/2012 21:15'!
testStrings
	| writer |
	writer := [ :object | 
		String streamContents: [ :stream |
			(NeoJSONWriter on: stream) nextPut: object ] ].
	self assert: (writer value: 'foo') equals: '"foo"'.
	self assert: (writer value: 'Foo BAR') equals: '"Foo BAR"'.
	self assert: (writer value: '') equals: '""'.
	self
		assert: (writer value: (String withAll: { 
					$". $\. $/. Character tab. Character cr. Character lf.  Character newPage. Character backspace }))
		equals: '"\"\\/\t\r\n\f\b"'

! !

!NeoJSONWriterTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/8/2012 21:56'!
testSymbol
	| writer |
	writer := [ :object | 
		String streamContents: [ :stream |
			(NeoJSONWriter on: stream) nextPut: object ] ].
	self assert: (writer value: #foo) equals: '"foo"'.
	self assert: (writer value: #'FOO-1') equals: '"FOO-1"'
! !

!NeoJSONWriterTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/12/2012 12:02'!
testTime
	| writer |
	writer := [ :object | 
		String streamContents: [ :stream |
			(NeoJSONWriter on: stream) 
				for: Time customDo: [ :mapping |
					mapping encoder: [ :time | time print24 ] ];
				nextPut: object ] ].
	self assert: (writer value: (Time hour: 14 minute: 30 second: 8)) equals: '"14:30:08"'! !

Object subclass: #NeoJSONBenchmark
	instanceVariableNames: 'objects json'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Neo-JSON-Tests'!

!NeoJSONBenchmark commentStamp: 'SvenVanCaekenberghe 6/5/2012 09:48' prior: 0!
I am NeoJSONBenchmark.
I hold 1000 objects of the form Dictionary('color'->'green' 'enabled'->false 'id'->1 'name'->'Name-1' 'value'->0.002 ) in an Array.
I hold the JSON serialization of that as a String of the form '[{"value":0.002,"enabled":false,"name":"Name-1","color":"green","id":1}, ...

| benchmark |
benchmark := NeoJSONBenchmark new.
[benchmark read] bench.

| benchmark |
benchmark := NeoJSONBenchmark new.
[benchmark write] bench.

| benchmark |
benchmark := NeoJSONBenchmark new.
[benchmark read] timeToRun.

| benchmark |
benchmark := NeoJSONBenchmark new.
[benchmark write] timeToRun.!

!NeoJSONBenchmark methodsFor: 'initialize-release' stamp: 'SvenVanCaekenberghe 6/4/2012 18:49'!
initialize
	super initialize.
	objects := Array new: 1000.
	1 to: 1000 do: [ :each |
		| map |
		(map := Dictionary new)
			at: 'id' put: each;
			at: 'name' put: 'Name-', each asString;
			at: 'enabled' put: (#( true false) at: (each \\ 2) + 1);
			at: 'color' put: (#( 'red' 'green' 'blue' ) at: (each \\ 3) + 1);
			at: 'value' put: each + each / 1000.0.
		objects at: each put: map ].
	json := String streamContents: [ :stream |
		(NeoJSONWriter on: stream) nextPut: objects ]
		! !

!NeoJSONBenchmark methodsFor: 'public' stamp: 'SvenVanCaekenberghe 6/4/2012 17:02'!
read
	^ (NeoJSONReader on: json readStream) next
! !

!NeoJSONBenchmark methodsFor: 'public' stamp: 'SvenVanCaekenberghe 6/4/2012 17:26'!
write
	^ String streamContents: [ :stream |
		(NeoJSONWriter on: stream) nextPut: objects ]
! !

!NeoJSONBenchmark methodsFor: 'public' stamp: 'SvenVanCaekenberghe 6/6/2012 15:07'!
writePrettyPrintedRead
	| output |
	output := String streamContents: [ :stream |
		(NeoJSONWriter on: stream) 
			prettyPrint: true;
			nextPut: objects ].
	^ (NeoJSONReader on: output readStream) 
		next! !

Object subclass: #NeoJSONMockStream
	instanceVariableNames: 'stream'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Neo-JSON-Tests'!

!NeoJSONMockStream commentStamp: '<historical>' prior: 0!
I am NeoJSONMockStream.
I wrap another stream to validate the limited API used.!

!NeoJSONMockStream class methodsFor: 'instance creation' stamp: 'SvenVanCaekenberghe 6/13/2012 16:25'!
on: stream
	^ self new
		stream: stream;
		yourself! !

!NeoJSONMockStream methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/13/2012 16:23'!
atEnd
	^ stream atEnd! !

!NeoJSONMockStream methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/13/2012 16:23'!
close
	^ stream close! !

!NeoJSONMockStream methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/13/2012 16:22'!
next
	^ stream next! !

!NeoJSONMockStream methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/13/2012 16:23'!
nextPut: character
	^ stream nextPut: character! !

!NeoJSONMockStream methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/13/2012 16:23'!
nextPutAll: string
	^ stream nextPutAll: string! !

!NeoJSONMockStream methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/13/2012 16:22'!
peek
	^ stream peek! !

!NeoJSONMockStream methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 12/3/2012 10:53'!
peekFor: char
	^ stream peekFor: char! !

!NeoJSONMockStream methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/13/2012 16:23'!
space
	^ stream space! !

!NeoJSONMockStream methodsFor: 'initialize-release' stamp: 'SvenVanCaekenberghe 6/13/2012 16:22'!
stream: anObject
	stream := anObject! !

Object subclass: #NeoJSONTestObject1
	instanceVariableNames: 'id name timestamp points bytes'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Neo-JSON-Tests'!

!NeoJSONTestObject1 commentStamp: '<historical>' prior: 0!
I am NeoJSONTestObject1.

I repesent a domain model object.
I have the following properties:

- id <Integer>
- name <String>
- timestamp <DateAndTime>
- points <Array of: Point>
- bytes <ByteArray>

My JSON representation is like this:

- id <Number>
- name <String>
- created-at <ISO8601 String>
- points <Array of: <Map x,y>
- bytes <Array of: Number>
!

!NeoJSONTestObject1 class methodsFor: 'instance creation' stamp: 'SvenVanCaekenberghe 6/9/2012 18:06'!
example1
	^ self new
		id: 123;
		name: 'Example1';
		timestamp: (DateAndTime year: 2012 month: 06 day: 08 hour: 14 minute: 30 second: 15 offset: 1 hour);
		points: { 1@2. 3@4 };
		bytes: #[ 2 4 6 8 ];
		yourself! !

!NeoJSONTestObject1 class methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/12/2012 12:34'!
neoJsonMapping: mapper
	mapper for: self do: [ :mapping |
		mapping mapInstVars: #(id name).
		(mapping mapInstVar: #timestamp to: 'created-at') valueSchema: DateAndTime.
		(mapping mapInstVar: #points) valueSchema: #ArrayOfPoints.
		(mapping mapInstVar: #bytes) valueSchema: ByteArray ].
	mapper for: DateAndTime customDo: [ :mapping |
		mapping decoder: [ :string | DateAndTime fromString: string ].
		mapping encoder: [ :dateAndTime | dateAndTime printString ] ].
	mapper for: #ArrayOfPoints customDo: [ :mapping |
		mapping listOfElementSchema: Point ].  
	mapper mapAllInstVarsFor: Point.
	mapper for: ByteArray customDo: [ :mapping |
		mapping listOfType: ByteArray ]! !

!NeoJSONTestObject1 methodsFor: 'comparing' stamp: 'SvenVanCaekenberghe 6/9/2012 18:45'!
= anObject
	self == anObject
		ifTrue: [ ^ true ].
	self class = anObject class
		ifFalse: [ ^ false ].
	^ id = anObject id
		and: [
			name = anObject name
				and: [
					timestamp = anObject timestamp
						and: [
							points = anObject points
								and: [ bytes = anObject bytes ] ] ] ]! !

!NeoJSONTestObject1 methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/9/2012 18:03'!
bytes
	^ bytes! !

!NeoJSONTestObject1 methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/9/2012 18:04'!
bytes: byteArray
	bytes := byteArray! !

!NeoJSONTestObject1 methodsFor: 'comparing' stamp: 'SvenVanCaekenberghe 6/9/2012 18:46'!
hash
	^ id hash bitXor: (name hash bitXor: (timestamp hash bitXor: (points hash bitXor: bytes hash)))! !

!NeoJSONTestObject1 methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/9/2012 18:02'!
id
	^ id! !

!NeoJSONTestObject1 methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/9/2012 18:03'!
id: integer
	id := integer! !

!NeoJSONTestObject1 methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/9/2012 18:02'!
name
	^ name! !

!NeoJSONTestObject1 methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/9/2012 18:03'!
name: string
	name := string! !

!NeoJSONTestObject1 methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/9/2012 18:03'!
points
	^ points! !

!NeoJSONTestObject1 methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/9/2012 18:04'!
points: arrayOfPoints
	points := arrayOfPoints ! !

!NeoJSONTestObject1 methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/9/2012 18:03'!
timestamp
	^ timestamp! !

!NeoJSONTestObject1 methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/9/2012 18:03'!
timestamp: dateAndTime 
	timestamp := dateAndTime ! !

Object subclass: #NeoJSONTestObject2
	instanceVariableNames: 'id width height data'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Neo-JSON-Tests'!

!NeoJSONTestObject2 commentStamp: 'SvenVanCaekenberghe 3/22/2014 09:36' prior: 0!
I am NeoJSONTestObject2.

Instance Variables
	data:		<String>
	height:		<Integer>
	id:			<Integer>
	width:		<Integer>

Used for benchmarking and other tests.!

!NeoJSONTestObject2 class methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/10/2012 20:53'!
benchmark10k
	"self benchmark10k"
	
	self benchmark: 10000! !

!NeoJSONTestObject2 class methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/10/2012 20:54'!
benchmark10kAsDictionary
	"self benchmark10kAsDictionary"
	
	self benchmarkAsDictionary: 10000! !

!NeoJSONTestObject2 class methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/10/2012 20:54'!
benchmark200k
	"self benchmark200k"
	
	self benchmark: 200000! !

!NeoJSONTestObject2 class methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/10/2012 20:52'!
benchmark: count
	"self benchmark: 1000"
	
	| collection json size |
	collection := Array new: count withAll: self example1.
	size := 2 + (count * (NeoJSONWriter toString: self example1) size) + count - 1.
	Transcript 
		cr;
		<< ('Serializing {1} objects took ms ' format: { count });
		show: [ json := String new: size streamContents: [ :stream |
								(NeoJSONWriter on: stream) nextPut: collection ] ] timeToRun.
	Transcript 
		cr;
		<< ('Deserializing {1} objects took ms ' format: { count });
		show: [ NeoJSONReader fromString: json ] timeToRun.! !

!NeoJSONTestObject2 class methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/10/2012 20:53'!
benchmarkAsDictionary: count
	"self benchmarkAsDictionary: 1000"
	
	| collection json size |
	collection := Array new: count withAll: self example1 asDictionary.
	size := 2 + (count * (NeoJSONWriter toString: self example1 asDictionary) size) + count - 1.
	Transcript 
		cr;
		<< ('Serializing {1} objects took ms ' format: { count });
		show: [ json := String new: size streamContents: [ :stream |
								(NeoJSONWriter on: stream) nextPut: collection ] ] timeToRun.
	Transcript 
		cr;
		<< ('Deserializing {1} objects took ms ' format: { count });
		show: [ NeoJSONReader fromString: json ] timeToRun.! !

!NeoJSONTestObject2 class methodsFor: 'instance creation' stamp: 'SvenVanCaekenberghe 6/10/2012 20:04'!
example1
	^ self new
		id: 13;
		width: 250;
		height: 110;
		data: (String new: 512 withAll: $a);
		yourself! !

!NeoJSONTestObject2 class methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 3/22/2014 10:50'!
neoJsonMapping: mapper
	"For inheritance mapping to work, the schema/classname must be self,
	but the instance variables have to be enumerated manually per class"

	mapper for: self do: [ :mapping |
		mapping mapInstVars: #(id width height data) ] ! !

!NeoJSONTestObject2 methodsFor: 'comparing' stamp: 'SvenVanCaekenberghe 6/10/2012 20:22'!
= anObject
	self == anObject
		ifTrue: [ ^ true ].
	self class = anObject class
		ifFalse: [ ^ false ].
	^ id = anObject id
		and: [
			height = anObject height
				and: [
					width = anObject width
						and: [
							data = anObject data ] ] ]! !

!NeoJSONTestObject2 methodsFor: 'converting' stamp: 'SvenVanCaekenberghe 6/10/2012 20:47'!
asDictionary
	^ Dictionary new
		at: #id put: id;
		at: #height put: height;
		at: #width put: width;
		at: #data put: data;
		yourself! !

!NeoJSONTestObject2 methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/10/2012 20:04'!
data
	^ data! !

!NeoJSONTestObject2 methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/10/2012 20:04'!
data: anObject
	data := anObject! !

!NeoJSONTestObject2 methodsFor: 'comparing' stamp: 'SvenVanCaekenberghe 6/10/2012 20:22'!
hash
	^ id hash bitXor: (width hash bitXor: (height hash bitXor: data hash))! !

!NeoJSONTestObject2 methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/10/2012 20:04'!
height
	^ height! !

!NeoJSONTestObject2 methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/10/2012 20:04'!
height: anObject
	height := anObject! !

!NeoJSONTestObject2 methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/10/2012 20:04'!
id
	^ id! !

!NeoJSONTestObject2 methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/10/2012 20:04'!
id: anObject
	id := anObject! !

!NeoJSONTestObject2 methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/10/2012 20:04'!
width
	^ width! !

!NeoJSONTestObject2 methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/10/2012 20:04'!
width: anObject
	width := anObject! !

NeoJSONTestObject2 subclass: #NeoJSONTestObject3
	instanceVariableNames: 'color transparent'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Neo-JSON-Tests'!

!NeoJSONTestObject3 commentStamp: 'SvenVanCaekenberghe 3/22/2014 09:40' prior: 0!
I am NeoJSONTestObject3, a subclass of NeoJSONTestObject2.

Instance Variables
	color:			<String>
	transparent :	<Boolean>

I am used for inheritance testing.
!

!NeoJSONTestObject3 class methodsFor: 'instance creation' stamp: 'SvenVanCaekenberghe 3/22/2014 09:43'!
example1
	^ super example1
		data: (String new: 8 withAll: $a);
		color: 'red';
		transparent: true;
		yourself! !

!NeoJSONTestObject3 class methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 3/22/2014 10:50'!
neoJsonMapping: mapper
	"For inheritance mapping to work, the schema/classname must be self,
	but the instance variables have to be enumerated manually per class"
	
	super neoJsonMapping: mapper.
	mapper for: self do: [ :mapping |
		mapping mapInstVars: #(color transparent) ]! !

!NeoJSONTestObject3 methodsFor: 'comparing' stamp: 'SvenVanCaekenberghe 3/22/2014 09:45'!
= anObject
	^ super = anObject 
		and: [ color = anObject color
			and: [ transparent = anObject transparent ] ]! !

!NeoJSONTestObject3 methodsFor: 'converting' stamp: 'SvenVanCaekenberghe 3/22/2014 09:46'!
asDictionary
	^ super asDictionary
		at: #color put: color;
		at: #transparent put: transparent;
		yourself! !

!NeoJSONTestObject3 methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 3/22/2014 09:43'!
color
	^ color! !

!NeoJSONTestObject3 methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 3/22/2014 09:43'!
color: anObject
	color := anObject! !

!NeoJSONTestObject3 methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 3/22/2014 09:43'!
transparent
	^ transparent! !

!NeoJSONTestObject3 methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 3/22/2014 09:43'!
transparent: anObject
	transparent := anObject! !
